import Adafruit_BBIO.ADC as ADC                    # Import Adafruit library for Analog pins
import time                                        # Import library for sleep
import boto3                                       # Import boto3 library for AWS calls

aws_access_key = ""                                # AWS Access key
aws_access_secret_key = ""                         # AWS Secret access key

cloudwatch = boto3.client(                         # Use boto3 library for AWS Services
    'cloudwatch',                                  # Use cloudwatch client
    aws_access_key_id=aws_access_key,              # Programmatic credentials
    aws_secret_access_key=aws_access_secret_key,
    region_name='eu-west-1'                        # AWS Region
)


def sendCloudWatchMetrics(temperature):            # Method for pushing data to AWS CloudWatch
    cloudwatch.put_metric_data(                    # AWS CloudWatch PutMetricData call
        Namespace='Blog',                          # The namespace for the metric data
        MetricData=[                               # The data for the metric
            {
                'MetricName': 'Temperature',       # The name of the metric
                'Dimensions': [                    # The dimensions associated with the metric
                    {
                        'Name': 'Temperature',     # The name of the dimension
                        'Value': 'C'              # The value representing the dimension measurement
                    },
                ],
                'Value': temperature,              # Value that will be sent
                'Unit': 'Count'                    # AWS CloudWatch unit type
            },
        ]
    )


if __name__ == '__main__':
    ADC.setup()                                    # Configure Analog pins

    while True:
        read = ADC.read("P9_40")                   # Read output (voltage) of pin located at P9_40
        mv = read * 1800                           # 1.8V reference = 1800 mV
        temperature = (mv - 500)/10                # Calculation to extract Celsius values from voltage
        sendCloudWatchMetrics(float(temperature))  # Send current temperature to AWS CloudWatch
        print temperature
        time.sleep(15)                             # Wait 15 seconds before next measurement
